.. _index:

Documentation for *species*
===========================

*species* is a toolkit for spectral and photometric analysis of planetary and substellar atmospheres. The package has been developed and is maintained by |stolker|.

.. |stolker| raw:: html

	<a href="https://people.phys.ethz.ch/~stolkert/" target="_blank">Tomas Stolker</a>

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation
   tutorials/running_species.ipynb

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   overview
   configuration
   tutorials
   modules

.. toctree::
   :maxdepth: 2
   :caption: About species

   contributing
   about
